@@ -4,7 +4,7 @@ package Imager::Search;
 
 =head1 NAME
 
-Imager::Search - Locate images inside other images
+Imager::Search - Find images within other images
 
 =head1 SYNOPSIS
 
@@ -12,13 +12,13 @@ Imager::Search - Locate images inside other images
   
   # Load the pattern to search for
   my $pattern = Imager::Search::Pattern->new(
-      driver => 'Imager::Search::Driver::HTML8',
+      driver => 'Imager::Search::Driver::HTML24',
       file   => 'pattern.bmp',
   );
   
   # Load the image to search in
   my $image = Imager::Search::Image::File->new(
-      driver => 'Imager::Search::Driver::HTML8',
+      driver => 'Imager::Search::Driver::HTML24',
       file   => 'target.bmp',
   );
   
@@ -28,39 +28,39 @@ Imager::Search - Locate images inside other images
 
 =head1 DESCRIPTION
 
-For tasks involving searching for patterns within a string, the regular
-expression engine provided with Perl has demonstrated itself to be both
-fully featured and extremely fast.
+The regular expression engine provided with Perl has demonstrated itself
+to be both fully featured and extremely fast for tasks involving searching
+for patterns within a string.
 
-For tasks involving working with images, the CPAN module L<Imager> has
-demonstrated robust functionality across all common operating system
-platforms, while also being extremely fast.
+The CPAN module L<Imager> has demonstrated robust functionality and
+excellent speed across all common operating system platforms for tasks
+involving working with images.
 
-B<Imager::Search> takes the best features from L<Imager> and the regular
-expression engine and combines them to produce a simple pure perl image
-recognition engine for systems in which the images are pixel perfect.
+The goal of B<Imager::Search> takes the best features from L<Imager> and the
+regular expression engine and combines them to produce a simple pure perl
+image recognition engine for systems in which the images are pixel perfect.
 
 =head2 Use Cases
 
 L<Imager::Search> is intended to be useful for a range of tasks involving
-images from computing and the digital world.
-
-L<Imager::Search> is B<not> intended to be useful for functionality such
-as doing facial recognition or any other tasks involving real world
-images.
+images from computing systems and the digital world in general.
 
 The range of potential applications include monitoring screenshots from
-unmanned kiosk and advertising-screen computers for evidence of crashes
-or embarrasing popup messages, or automating interactions with
-graphics-intense desktop or website applications that would be otherwise
-intractable to traditional application automation methods.
+kiosk and advertising systems for evidence of crashes or embarrasing popup
+messages, automating interactions with graphics-intense desktop or website
+applications that would be otherwise intractable for traditional automation
+methods, and simple text recognition in systems with fonts that register to
+fixed pixel patterns.
 
-For example, by storing captured image fragments of a set of cards,
-a program might conceptually be able to look at a solitaire-type game
-and establish the position and identity of all the cards on the screen,
+For example, by storing captured image fragments of a sample set of playing
+cards, a program might conceptually be able to look at a solitaire-type
+game and establish the position and identity of all the cards on the screen,
 populating a model of the current game state and then allowing the
 automation of the playing of the game.
 
+L<Imager::Search> is B<NOT> intended to be useful for tasks such as facial
+recognition or any other tasks involving real world images.
+
 =head2 Methodology
 
 Regular expressions are domain-specific Non-Finite Automata (NFA)
@@ -76,18 +76,17 @@ translating the results of the run back into image terms, we can
 determine the specific location of all instances of the search image
 inside the target image with relative ease.
 
-By decomposing the problem of image recognition to a regular expression,
-the problem then become the creation of a series of transforms for
-generating a suitable search expression, generating a suitable target
-string, and deriving the match locations in image terms while removing
-any false positive or false negative results.
+By decomposing the image recognition task into a regular expression task,
+the problem then becomes how to define a series of transforms that can
+generate a suitable search expression, generate a suitable target
+string, and derive the match locations in pixel terms from match locations
+in character/byte terms.
 
 =head2 The Driver API
 
-While it is fairly easy to conceive of what a potential solution
-might look like (for example, by expressing each pixel as a HTML colour
-like #000000) the implementation is complicated by the need for all the
-code surrounding the regular expression execution to be fast as well.
+While it is fairly easy to conceive of what a potential solution might look
+like, implementing any solution is complicated by the need for all the code
+surrounding the regular expression execution to be fast as well.
 
 For example, a 0.01 second regular expression search time is of no value
 if compiling the search and target images takes several seconds.
@@ -101,44 +100,47 @@ expressions are cached and applied to many target images, versus cases
 where compiled target images are cached and search over by many search
 expressions.
 
-In a typically Perl fasion, L<Imager::Search> responds to this situation
-by not imposing a single solution, but instead defining a driver API for
-the transforms, so that a number of different implementations can be used
-with the same API in various situations.
+L<Imager::Search> responds to this ambiguity by not imposing a single
+solution, but instead defining a driver API for the transforms, so that
+a number of different implementations can be used with the same API in
+various situations.
 
-=head2 The HTML8 Driver
+=head2 The HTML24 Driver
 
-A default "HTML8" implementation is provided with the module. This is a
-reference driver that encodes each pixel as a HTML "#RRGGBB" colour code.
+A default "HTML24" implementation is provided with the module. This is a
+reference driver that encodes each pixel as a 24-bit HTML "#RRGGBB" colour
+code.
 
-This driver demonstrates fast search times and a simple results transform,
-but has an extremely slow method for generating the target images, as slow
-as several seconds for a typical screenshot.
+This driver demonstrates fast search times and a simple match resolution,
+but has an extremely slow method for generating the target images (as slow
+as 10 gigacyles for a typical 1024x768 pixel screenshot).
 
-Additional faster drivers are already being considered and will hopefully
-become available shortly.
+Faster drivers are currently being pursued.
 
 =head1 USAGE
 
-The current incarnation of L<Imager::Search> is still, so while the
-API for the individual classes are relatively stable, there is not yet
-a top level convenience API in the B<Imager::Search> namespace itself.
+This new second-generation incarnation of L<Imager::Search> is still in
+flux, so while the API for the individual classes are relatively stable,
+there is not yet a top level convenience API in the B<Imager::Search>
+namespace itself, and the driver API is still being substantially changed
+in response to the differing needs of different styles of driver.
 
-The typical usage pattern consists of the following steps...
+However a typical (if verbose) usage can be demonstrated, that should
+continue to work for a while...
 
 =head2 1. Load the Search Image
 
   # An image loaded from a file
   use Imager::Search::Image::File ();
   my $image = Imager::Search::Image::File->new(
-      driver => 'Imager::Search::Driver::HTML8',
+      driver => 'Imager::Search::Driver::HTML24',
       file   => 'target.bmp',
   );
   
   # An image captured from a screenshot
   use Imager::Search::Image::Screenshot ();
   my $screen = Imager::Search::Image::Screenshot->new(
-      driver => 'Imager::Search::Driver::HTML8',
+      driver => 'Imager::Search::Driver::HTML24',
   );
 
 =head2 2. Load the Search Pattern
@@ -146,7 +148,7 @@ The typical usage pattern consists of the following steps...
   # A pattern loaded from a file
   use Imager::Search::Pattern ();
   my $pattern = Imager::Search::Pattern->new(
-      driver => 'Imager::Search::Driver::HTML8',
+      driver => 'Imager::Search::Driver::HTML24',
       file   => 'pattern.bmp',
   );
 
@@ -178,11 +180,16 @@ L<Imager::Search::Driver> is the abstract driver interface. It cannot
 be instantiated directly, but it describes (in both code and documentation)
 what any driver needs to implement.
 
-=head2 Imager::Search::Driver::HTML8
+=head2 Imager::Search::Driver::HTML24
 
-L<Imager::Search::Driver::HTML8> is an 8-bit reference driver that uses
+L<Imager::Search::Driver::HTML24> is an 8-bit reference driver that uses
 HTML colour codes (#RRGGBB) to represent each pixel.
 
+=head2 Imager::Search::Driver::BMP24
+
+L<Imager::Search::Driver::BMP24> is an experimental 24-bit driver that uses
+the Windows BMP file format natively as it's image string format.
+
 =head2 Imager::Search::Image
 
 L<Imager::Search::Image> describes the abstract interface for a search
@@ -213,7 +220,7 @@ use Carp ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.11';
+	$VERSION = '0.12';
 }
 
 use Imager::Search::Pattern ();
