@@ -4,13 +4,13 @@ package Imager::Search::Driver;
 
 =head1 NAME
 
-Imager::Search::Driver - Locate an image inside another image
+Imager::Search::Driver - Abstract imlementation of a Imager::Search driver
 
 =head1 SYNOPSIS
 
   # Create the search
   my $search = Imager::Search::Driver->new(
-      driver => 'HTML8',
+      driver => 'HTML24',
       big    => $large_imager_object,
       small  => $small_imager_object,
   );
@@ -23,10 +23,6 @@ Imager::Search::Driver - Locate an image inside another image
 
 =head1 DESCRIPTION
 
-B<THIS MODULE IS CONSIDERED EXPERIMENTAL AND SUBJECT TO CHANGE>
-
-This module is designed to solve a conceptually simple problem.
-
 Given two images (we'll call them Big and Small), where Small is
 contained within Big zero or more times, determine the pixel locations
 of Small within Big.
@@ -41,7 +37,7 @@ scenarios, or desktop gui automation, and so on.
 
 =cut
 
-use 5.005;
+use 5.006;
 use strict;
 use Carp         ();
 use Params::Util qw{ _STRING _CODELIKE _SCALAR _INSTANCE };
@@ -49,9 +45,11 @@ use Imager       ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.11';
+	$VERSION = '0.12';
 }
 
+use Imager::Search::Match ();
+
 
 
 
@@ -76,45 +74,40 @@ sub new {
 
 	# Apply the default driver
 	if ( $class eq 'Imager::Search::Driver' ) {
-		require Imager::Search::Driver::HTML8;
-		return  Imager::Search::Driver::HTML8->new(@_);
+		require Imager::Search::Driver::HTML24;
+		return  Imager::Search::Driver::HTML24->new(@_);
 	}
 
 	# Create the object
 	my $self = bless { @_ }, $class;
 
-	# Get the transforms
-	unless ( _CODELIKE($self->transform_pattern_line) ) {
-		Carp::croak("The small_transform param was not a CODE reference");
-	}
-	unless ( _CODELIKE($self->transform_image_line) ) {
-		Carp::croak("The big_transform param was not a CODE reference");
-	}
-	unless ( _CODELIKE($self->transform_pattern_newline) ) {
-		Carp::croak("The transform_pattern_newline param was not a CODE reference");
-	}
-
 	return $self;
 }
 
 
 
 
+
 #####################################################################
 # Driver API Methods
 
+sub pattern_regexp {
+	my $class = ref($_[0] || $_[0]);
+	die "Illegal driver $class does not implement pattern_regexp";
+}
+
 sub pattern_lines {
 	my $self   = shift;
 	my $image  = shift;
 	my $height = $image->getheight;	
 	my @lines  = ();
 	foreach my $row ( 0 .. $height - 1 ) {
-		$lines[$row] = $self->pattern_scanline($image, $row);
+		$lines[$row] = $self->pattern_line($image, $row);
 	}
 	return \@lines;
 }
 
-sub pattern_scanline {
+sub pattern_line {
 	my ($self, $image, $row) = @_;
 
 	# Get the colour array
@@ -143,21 +136,58 @@ sub pattern_scanline {
 }
 
 sub image_string {
-	my $self       = shift;
-	my $scalar_ref = shift;
-	my $image      = shift;
-	my $height     = $image->getheight;
-	my $func       = $self->transform_image_line;
-	foreach my $row ( 0 .. $height - 1 ) {
-		# Get the string for the row
-		$$scalar_ref = join('',
-			map { &$func( $_ ) }
-			$image->getscanline( y => $row )
-		);
+	my $class = ref($_[0] || $_[0]);
+	die "Illegal driver $class does not implement image_string";
+}
+
+sub match_object {
+	my $self      = shift;
+	my $image     = shift;
+	my $pattern   = shift;
+	my $character = shift;
+
+	# Derive the pixel position from the character position
+	my $pixel   = $self->match_pixel( $image, $pattern, $character );
+
+	# Some drivers might return a match in some junk header
+	# information, before the beginning of the pixels.
+	unless ( $pixel >= 0 ) {
+		return; # undef or null list
 	}
 
-	# Return the scalar reference as a convenience
-	return $scalar_ref;
+	# If the pixel position isn't an integer we matched
+	# at a position that is not a pixel boundary, and thus
+	# this match is a false positive. Shortcut to fail.
+	unless ( $pixel == int($pixel) ) {
+		return; # undef or null list
+	}
+
+	# Calculate the basic geometry of the match
+	my $top    = int( $pixel / $image->width );
+	my $left   = $pixel % $image->width;
+
+	# If the match overlaps the newline boundary or falls off the bottom
+	# of the image, this is also a false positive. Shortcut to fail.
+	if ( $left > $image->width - $pattern->width ) {
+		return; # undef or null list
+	}
+	if ( $top > $image->height - $pattern->height ) {
+		return; # undef or null list
+	}
+
+	# This is a legitimate match.
+	# Convert to a match object and return.
+	return Imager::Search::Match->new(
+		top    => $top,
+		left   => $left,
+		height => $pattern->height,
+		width  => $pattern->width,
+	);
+}
+
+sub match_pixel {
+	my $class = ref($_[0] || $_[0]);
+	die "Illegal driver $class does not implement match_pixel";
 }
 
 1;
