@@ -17,7 +17,7 @@ use Params::Util qw{ _POSINT _INSTANCE };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.11';
+	$VERSION = '0.12';
 }
 
 sub new {
@@ -61,11 +61,6 @@ sub string {
 	$_[0]->{string};
 }
 
-sub transformed {
-	my $self = shift;
-	die "The transformed_string method must be implemented by a child class";
-}
-
 
 
 
@@ -97,9 +92,9 @@ sub find {
 	while ( scalar $$string =~ /$regexp/gs ) {
 		my $p = $-[0];
 		push @match, $self->driver->match_object( $self, $pattern, $p );
-		pos $string = $p + 1;
+		pos $$string = $p + 1;
 	}
-	return @match;
+	return sort { $a->top <=> $b->top } @match;
 }
 
 =pod
@@ -138,7 +133,24 @@ sub find_first {
 # Derived from find_first, but always return a scalar boolean
 sub find_any {
 	my $self  = shift;
-	return !! $self->find_first( @_ );
+
+	# Get the search expression
+        my $pattern = _INSTANCE(shift, 'Imager::Search::Pattern')
+		or die "Did not pass a Pattern object to find";
+	my $regexp  = $pattern->regexp( $self );
+
+	# Run the search
+	my $string = $self->string;
+	while ( scalar $$string =~ /$regexp/gs ) {
+		my $p = $-[0];
+		if ( defined $self->driver->match_object( $self, $pattern, $p ) ) {
+			return 1;
+		}
+
+		# False positive
+		pos $$string = $p + 1;
+	}
+	return '';
 }
 
 1;
